ColumnSortPredicateBuilder class

Inheritance

Properties

documentKeyPath List?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
order String
finalinherited
property ManagedPropertyDescription?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sqlOrderBy String
no setteroverride
table TableBuilder?
finalinherited

Methods

convertValueForStorage(dynamic value) → dynamic
inherited
convertValueFromStorage(dynamic value) → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sqlColumnName({bool withTableNamespace = false, String? withPrefix}) String
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited