ColumnValueBuilder class
- Inheritance
-
- Object
- Returnable
- ColumnBuilder
- ColumnValueBuilder
Constructors
- ColumnValueBuilder(TableBuilder table, ManagedPropertyDescription property, dynamic value)
Properties
- documentKeyPath → List?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- property → ManagedPropertyDescription?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- table → TableBuilder?
-
finalinherited
- value ↔ Object?
-
getter/setter pair
Methods
-
convertValueForStorage(
dynamic value) → dynamic -
inherited
-
convertValueFromStorage(
dynamic value) → dynamic -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sqlColumnName(
{bool withTableNamespace = false, String? withPrefix}) → String -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited